#
# spec file for package python-jaraco.envs
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-jaraco.envs
VCS: https://src.suse.de/SLFO-pool/python-jaraco.envs#58b353350ff35e71229e5950ee81a89d01c629fc89d1faf03773fed8f24c69a3
Version:        2.6.0
Release:        160000.1.4
Summary:        Classes for Python Virtual Environments
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/jaraco/jaraco.envs
Source0:        https://files.pythonhosted.org/packages/source/j/jaraco.envs/jaraco.envs-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 56}
BuildRequires:  %{python_module setuptools_scm >= 3.4.1}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-path
Requires:       python-virtualenv
Recommends:     python-tox
BuildArch:      noarch
# SECTION test
BuildRequires:  %{python_module pytest >= 6}
BuildRequires:  %{python_module path}
BuildRequires:  %{python_module virtualenv}
# /SECTION
%python_subpackages

%description
Classes for orchestrating Python (virtual) environments.

%prep
%setup -q -n jaraco.envs-%{version}
# Avoid tox in openSUSE:Factory:Rings:1-MinimalX
sed -i '/tox/d' setup.cfg

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -k "not envs.VirtualEnv"

%files %{python_files}
%license LICENSE
%doc docs/*.rst README.rst NEWS.rst
%{python_sitelib}/jaraco.envs-%{version}*info
%dir %{python_sitelib}/jaraco
%{python_sitelib}/jaraco/envs.py*
%pycache_only %dir %{python_sitelib}/jaraco/__pycache__
%pycache_only %{python_sitelib}/jaraco/__pycache__/envs*.py*

%changelog
* Sat Jan 13 2024 dmueller@suse.com
- update to 2.6.0:
  * Environments now have a default name, '.venv'.
  * Remove Python 3.7 compatibility from tests.
  * Require Python 3.8 or later.
* Fri Apr 21 2023 dmueller@suse.com
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 mcepl@suse.com
- Make calling of %%{sle15modernpython} optional.
* Mon Aug 29 2022 code@bnavigator.de
- Do not own the jaraco toplevel directory (PEP440 namespace pkg)
- Clean specfile from old distro code
* Wed Jul 13 2022 code@bnavigator.de
- Update to version 2.4.0
  * Made VEnv non-experimental.
- Release v2.3.0
  * #4: Added some tests capturing expectations around object types
    for input (use path.Path object for root property for maximum
    compatibility).
  * Require Python 3.7 or later.
  * VirtualEnv classes now expose clean_opts for easy reference in
    creating clean environments.
- Release v2.2.0
  * VirtualEnv now allows a create_opts attribute to affect the
    creation (passed to virtualenv).
- Release v2.1.1
  * Rely on PEP 420 for namespace packages.
- Release v2.1.0
  * #1: Rely on pure tox without tox-venv.
* Sun Apr 19 2020 mrueckert@suse.de
- fix egg info path
* Sun Apr 19 2020 mrueckert@suse.de
- update BR according to setup.cfg
* Thu Mar 26 2020 pgajdos@suse.com
- initial version 2.0.0, required by python-twine testsuite
